@@ -4,6 +4,8 @@ import time
 import glob
 import json
 import datetime
+import string
+import random
 from pathlib import Path
 import re
 import logging
@@ -20,21 +22,17 @@ logger = logging.getLogger(__name__)
 CLEANUP_INTERVAL_MS = 0.999
 
 
+def random_token(length=10):
+    alphabet = string.ascii_letters + string.digits
+    return join(random.choice(alphabet) for i in range(length))
+
+
 class BatchProcessor:
     def __init__(self, config):
+        self.worker_id = random_token(10)
         self.config = config
         self.do_log = self.config.get("batch-log-logging", True)
         self.last_cleanup_time = datetime.datetime.now()
-        # How many ids to batch simultaneously
-        # self.batch_size=self.config.get('batch-log-batch-size', 10)
-        # self.item_types=['scrape']
-        # self.item_queues={}
-        # for type in self.item_types:
-        # 	self.item_queues[type]=Queue(self.batch_size)
-        # Lock to synchronize access to our source of new ids to try
-        # self.id_source_lock=threading.Lock()
-        # How many simultaneous threads will be processing batch items?
-        # self.thread_count=1
         self.task_filter = re.compile("^([0-9a-z\-_]+(\/[0-9a-z\-_]+)*)$")
         self.last_status_time = None
         self.callables = {}
@@ -43,6 +41,11 @@ class BatchProcessor:
             logger.warning("Skipping database initialization")
         else:
             self.db = Database(self.config)
+        logger.warning(f"Batch Processor {self.worker_id} instanciated")
+
+    def __del__(self):
+        logger.warning(f"Batch Processor {self.worker_id} deleted")
+        self.worker_id = None
 
     def verify(self):
         modules = self.list_modules()
@@ -75,11 +78,6 @@ class BatchProcessor:
             spec = importlib.util.spec_from_file_location(module_name, module_filepath)
             spec.submodule_search_locations = list(__import__(__name__).__path__)
             module = importlib.util.module_from_spec(spec)
-            # logger.info(f"ORIG MODULE PATH: {pformat(module.__path__)}")
-            # logger.info(f"PARENT PATH: {pformat(__import__(__name__).__path__)}")
-            # module.__path__= __import__(__name__).__path__
-            # logger.info(f"UPDATED MODULE PATH: {pformat(module.__path__)}")
-            # sys.modules[spec.name] = module
             spec.loader.exec_module(module)
         except Exception as e:
             failure = f"Import of module '{module_name}'from file '{module_filepath}' had errors ({e}). (Spec was {pprint.pformat(spec)})"
@@ -178,9 +176,7 @@ class BatchProcessor:
             if os.path.exists(module_filepath):
                 if fk.utils.file_contains_str(module_filepath, self.entry_name):
                     try:
-                        # module = importlib.import_module(module_name)
                         module, failure = self.load_module_by_filepath(module_name, module_filepath)
-                        # module, failure = self.load_module_by_package('fk.batch.filters.'+module_name)
                         if module:
                             if hasattr(module, self.entry_name):
                                 entry_method = getattr(module, self.entry_name)
@@ -240,7 +236,7 @@ class BatchProcessor:
             logger.warning("")
             logger.warning("")
             logger.warning(f"###############################################")
-            logger.warning(f"#    Batch item: {item}")
+            logger.warning(f"#    Batch item: {item} on worker {self.worker_id}")
             logger.warning(f"# Failed with: {e} ({type(e).__name__}, {e.args})")
             failure = f"{e}  ({type(e).__name__}, {e.args})"
             logger.warning(f"#          At:")
@@ -259,7 +255,7 @@ class BatchProcessor:
         """
         Take ownership of one batch item and make sure it is properly executed and updated with status underway
         """
-        item = self.db.book_batch_item(self.db.PENDING, self.db.IN_PROGRESS)
+        item = self.db.book_batch_item(self.db.PENDING, self.db.IN_PROGRESS, self.worker_id)
         if item:
             if self.do_log:
                 logger.info("Processing item:")
@@ -294,7 +290,7 @@ class BatchProcessor:
         Take ownership of one batch item and make sure it is properly executed and updated with status underway
         NOTE: Throttled version
         """
-        item = self.db.book_throttled_batch_item(self.db.PENDING, self.db.IN_PROGRESS)
+        item = self.db.book_throttled_batch_item(self.db.PENDING, self.db.IN_PROGRESS, self.worker_id)
         if item:
             if self.do_log:
                 logger.info("Processing item:")
@@ -408,10 +404,6 @@ class BatchProcessor:
         # fmt: off
         status = {
              "status": self.db.get_status_counts()
-#           , "last": self.db.get_jobs(limit=20),
-#           , "last_failed": self.db.get_jobs(limit=20, status=["failed"]),
-#           , "last_pending": self.db.get_jobs(limit=20, status=["pending"]),
-#           , "last_in_progress": self.db.get_jobs(limit=20, status=["in-progress"]),
             , "counts": self.get_job_counts()
             , "times": self.get_job_times()
         }
@@ -426,8 +418,5 @@ class BatchProcessor:
             self._update_hang_status()
         # Try to process one item
         if not self.execute_one_throttled_batch_item():
-            # Put a status
-            # if not self.last_status_time or (datetime.now() - self.last_status_time).total_seconds() > 10.0:
-            # 	self.print_status()
             # Lets not get stuck in a loop!
             time.sleep(1)
