@@ -35,6 +35,7 @@ class Database:
                 , throttle_period integer
                 , source text
                 , error text
+                , worker_id varchar(63) default null
                 , last_started_at timestamptz
                 , last_finished_at timestamptz
                 , created_at timestamptz not null default now()
@@ -52,6 +53,7 @@ class Database:
             comment on column batch_log.throttle_period is 'When throttle_key is set, this specifies the period over which throttle_limit items may be processed';
             comment on column batch_log.source is 'The batch item''s source. Spesifically which component registered it.';
             comment on column batch_log.error is 'The batch item''s error message. Should be None unless status is "failed", in which it case it should be a descriptive error message.';
+            comment on column batch_log.worker_id is 'The ID of the worker that last processed this item, or Null if it was not yet processed.';
             comment on column batch_log.last_started_at is 'When the batch item last started (entered in_progress state)';
             comment on column batch_log.last_finished_at is 'When the batch item last finished (exited in_progress state)';
             comment on column batch_log.created_at is 'When the batch item was first created';
@@ -335,7 +337,7 @@ $$ language plpgsql;
         )
 
     # Update a batch item in the batch log, making sure to fail if the id and updated_at don't match, providing a guarantee of atomic operation
-    def book_batch_item(self, from_status=PENDING, to_status=IN_PROGRESS):
+    def book_batch_item(self, from_status=PENDING, to_status=IN_PROGRESS, worker_id=None):
         return self.dbc.query_one(
             """
                 update
@@ -363,8 +365,9 @@ $$ language plpgsql;
                           else
                               b.last_finished_at
                       end)
-                    , status=%(to_status)s
-                    , updated_at=now()
+                    , worker_id = %(worker_id)s
+                    , status = %(to_status)s
+                    , updated_at = now()
                 where
                     status = %(from_status)s
                 and
@@ -395,12 +398,12 @@ $$ language plpgsql;
                     , updated_at
                 ;
                 """,
-            {"from_status": (from_status,), "to_status": (to_status,), "in_progress_status": (self.IN_PROGRESS,)},
+            {"from_status": (from_status,), "to_status": (to_status,), "in_progress_status": (self.IN_PROGRESS,), "worker_id": (worker_id,)},
         )
 
     # Update a batch item in the batch log, making sure to fail if the id and updated_at don't match, providing a guarantee of atomic operation
     # NOTE: This is the throttled version
-    def book_throttled_batch_item(self, from_status=PENDING, to_status=IN_PROGRESS):
+    def book_throttled_batch_item(self, from_status=PENDING, to_status=IN_PROGRESS, worker_id=None):
         return self.dbc.query_one(
             """
                 update
@@ -428,8 +431,9 @@ $$ language plpgsql;
                           else
                               b.last_finished_at
                       end)
-                    , status=%(to_status)s
-                    , updated_at=now()
+                    , worker_id = %(worker_id)s
+                    , status = %(to_status)s
+                    , updated_at = now()
                 where
                     status = %(from_status)s
                 and
@@ -462,7 +466,7 @@ $$ language plpgsql;
                     , updated_at
                 ;
                 """,
-            {"from_status": (from_status,), "to_status": (to_status,), "in_progress_status": (self.IN_PROGRESS,)},
+            {"from_status": (from_status,), "to_status": (to_status,), "in_progress_status": (self.IN_PROGRESS,), "worker_id": (worker_id,)},
         )
 
     # Delete single item by id
